==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Koledar",
    "%s has published the calendar \"%s\"" : "%s je objavil koledar \"%s\"",
    "Too many redirects. Aborting ..." : "Preveč preusmeritev. Odstopam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Oddaljeni strežnik nam ni dovolil dostopa koledarja(HTTP {%s} napaka)",
    "Error connecting to remote server" : "Napaka pri povezovanju na strežnik",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Napaka med zahtevanjem virov na strežniku. To je lahko povezano z napako certifikata",
    "Error requesting resource on remote server" : "Napaka med zahtevanjem virov na strežniku",
    "Individual" : "Posamezno",
    "Group" : "Skupina",
    "Resource" : "Vir",
    "Room" : "Soba",
    "Unknown" : "Neznano",
    "Required" : "Zahtevano",
    "Optional" : "Izbirno",
    "Does not attend" : "Ni udeleženec",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ni mogoče določiti časovnega pasu ({tz}), zato bo prikazan čas UTC",
    "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
    "New event" : "Nov dogodek",
    "CalDAV address for clients" : "CalDAV naslov za odjemalce",
    "Error saving WebCal-calendar" : "Napaka shranjevanja koledarja WebCal",
    "WebDAV address for subscriptions" : "WebDAV naslov za naročnike",
    "EMail has been sent." : "E-pošta je bila poslana.",
    "There was an issue while sending your EMail." : "Prišlo je do napake pri pošiljanju e-pošte.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Udeleženci",
    "Reminders" : "Opomniki",
    "Repeating" : "Ponavljanje",
    "When shared show full event" : "Če je v souporabi, pokaži celoten dogodek",
    "When shared show only busy" : "Če je v souporabi, pokaži le podatek o časovni zadržanosti",
    "When shared hide this event" : "Če je v souporabi, skrij ta dogodek",
    "Confirmed" : "Potrjeno",
    "Tentative" : "Začasno",
    "Cancelled" : "Preklicano",
    "Please add a title!" : "Dodajte naslov!",
    "Please select a calendar!" : "Izberite koledar!",
    "The event ends before it starts!" : "Dogodek se je končal, preden se je začnel!",
    "Global" : "Splošno",
    "None" : "Brez",
    "Every day" : "Vsak dan",
    "Every week" : "Vsak teden",
    "Every month" : "Vsak mesec",
    "Every year" : "Vsako leto",
    "never" : "nikoli",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Kaj če bi najprej poskusil uvoziti kakšen koledar?",
    "At time of event" : "Ob času dogodka",
    "5 minutes before" : "5 minut prej",
    "10 minutes before" : "10 minut prej",
    "15 minutes before" : "15 minut prej",
    "30 minutes before" : "30 minut prej",
    "1 hour before" : "1 uro prej",
    "2 hours before" : "2 uri prej",
    "Custom" : "Po meri",
    "Audio" : "Zvok",
    "E Mail" : "Elektronska pošta",
    "Pop up" : "Pojavno okno",
    "sec" : "sek",
    "min" : "najmanj",
    "hours" : "ur",
    "days" : "dni",
    "week" : "teden",
    "before" : "pred",
    "start" : "začetek",
    "end" : "konec",
    "Editing reminders of unknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
    "Week {number} of {year}" : "{number}. teden leta {year}",
    "Successfully imported" : "Uvoz uspešno končan",
    "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
    "Partially imported, {n} failures" : "Delno uvoženo, zaznanih je {n} napak",
    "Audio alarm" : "Zvočni alarm",
    "Pop-up" : "Pojavno okno",
    "E-Mail" : "Elektronska pošta",
    "{type} {time} before the event starts" : "{type} {time} preden se dogodek začne",
    "{type} {time} before the event ends" : "{type} {time} preden se dogodek konča",
    "{type} {time} after the event starts" : "{type} {time} po začetku dogodka",
    "{type} {time} after the event ends" : "{type} {time} po koncu dogodka",
    "{type} at the event's start" : "{type} ob začetku dogodka",
    "{type} at the event's end" : "{type} ob koncu dogodka",
    "{type} at {time}" : "{type} ob {time}",
    "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
    "Please enter a valid WebCal-URL" : "Vpišite veljaven naslov URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Resna težava na  webcal proxy. Prosim, kontaktiraj administratorja za dodatne informacije.",
    "Title of the Event" : "Naslov dogodka",
    "Starts" : "Začel",
    "Ends" : "Končal",
    "All day Event" : "Celodnevni dogodek",
    "Delete" : "Izbriši",
    "Cancel" : "Prekliči",
    "More ..." : "Več ...",
    "Create" : "Ustvari",
    "Update" : "Posodobi",
    "Close" : "Zapri",
    "Location" : "Mesto",
    "Description" : "Opis",
    "Event status" : "Stanje dogodka",
    "Visibility when sharing" : "Vidnost med souporabo",
    "Export" : "Izvozi",
    "%s has published the calendar %s" : "%s je objavil koledar \"%s\"",
    "Hello," : "Živjo,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Te želimo obvestiti, da je %s objavil(a) koledar {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikni tukaj za dostop.",
    "Cheers!" : "Lep pozdrav!",
    "We wanted to inform you that %s has published the calendar %s." : "Te želimo obvestiti, da je %s objavil(a) koledar %s.",
    "Click on the link below to access it" : "Klikni na povezavo, da jo lahko dostopaš",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Zaradi znanega hrošča v koledarju trenutno ni mogoča podpora zmožnosti skrčenja kode javascript in CSS.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Stopite v stik s sistemskim skrbnikom oziroma onemogočite nastavitev \"asset-pipeline.enabled\"",
    "Day" : "Dan",
    "Week" : "Teden",
    "Month" : "Mesec",
    "Today" : "Danes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
    "Share Calendar" : "Omogoči souporabo koledarja",
    "Shared" : "V souporabi",
    "More" : "Več",
    "Edit" : "Uredi",
    "Link" : "Povezava",
    "iCal link" : "iCal povezava",
    "Download" : "Prejmi",
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "can edit" : "lahko ureja",
    "Share link" : "Povezava skupne rabe",
    "Public access" : "Javni dostop",
    "Email link to person" : "Pošlji osebi povezavo po e-pošti",
    "Send" : "Pošlji",
    "New Calendar" : "Nov koledar",
    "Name" : "Ime",
    "New Subscription" : "Novo naročilo",
    "Go back" : "Nazaj",
    "Go forward" : "Naprej",
    "Calendar does not exist" : "Koledar ne obstaja",
    "Maybe you got a wrong link or the calendar was unshared?" : "Mogoče imaš napačno povezavo ali koledar nima skupne rabe?",
    "Edit event" : "Uredi dogodek",
    "Delete Event" : "Izbriši dogodek",
    "Save Event" : "Shrani dogodek",
    "Time" : "Čas",
    "Type" : "Vrsta",
    "Relative" : "Relativno",
    "Absolute" : "Absolutno",
    "Repeat" : "Ponovi",
    "times every" : "krat vsakih",
    "Add" : "Dodaj",
    "E-Mail address of attendee" : "Elektronski naslov udeleženca",
    "Please add your email address in the personal settings in order to add attendees." : "Dodati morate vaš elektronski naslov med osebne nastavitve, preden je mogoče dodajati udeležence",
    "from" : "od",
    "to" : "za",
    "This event's repeating rule is not supported yet." : "Ponavljajoče pravilo tega dogodka še ni podprto.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora naprednejšim pravilom bo dodana z naslednjimi posodobitvami.",
    "Reset repeating rule" : "Ponastavi ponavljajoče se pravilo",
    "Repeat every ..." : "Ponovi na ..",
    "end repeat ..." : "in ponovi ...",
    "times" : "krat",
    "Import Calendars" : "Uvoz koledarjev",
    "Import canceled" : "Uvoz je preklican",
    "Analyzing calendar" : "Preučevanje koledarja",
    "The file contains objects incompatible with the selected calendar" : "Datoteka vsebuje predmete, ki so neskladne z izbranim koledarjem",
    "New calendar" : "Nov koledar",
    "File is empty" : "Datoteka je prazna",
    "Import scheduled" : "Uvoz urnika",
    "%s shared the calendar <strong>%s</strong> with you" : "%s skupno rabo koledarja <strong>%s</strong> z vami",
    "Publish URL" : "Objavi URL",
    "Settings & import" : "Nastavitve in uvoz",
    "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
    "Show week numbers" : "Pokaži številke tednov",
    "Import calendar" : "Uvoz koledarja",
    "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
    "Primary CalDAV address" : "Osnovni naslov CalDAV",
    "iOS/OS X CalDAV address" : "Naslov CalDAV iOS/OS",
    "Subscribe" : "Naročite se"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-calendar-1.5.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Koledar",
    "%s has published the calendar »%s«" : "%s je objavil koledar \"%s\"",
    "Hello," : "Živjo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Želimo te obvestiti, da je %s objavil(a) koledar %s.",
    "Open »%s«" : "Odpri »%s«",
    "Cheers!" : "Lep pozdrav!",
    "Recipient" : "Prejemnik",
    "Too many redirects. Aborting ..." : "Preveč preusmeritev. Odstopam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Oddaljeni strežnik nam ni dovolil dostopa koledarja(HTTP {%s} napaka)",
    "Error connecting to remote server" : "Napaka pri povezovanju na strežnik",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Napaka med zahtevanjem virov na strežniku. To je lahko povezano z napako certifikata",
    "Error requesting resource on remote server" : "Napaka med zahtevanjem virov na strežniku",
    "Individual" : "Posamezno",
    "Group" : "Skupina",
    "Resource" : "Vir",
    "Room" : "Soba",
    "Unknown" : "Neznano",
    "Required" : "Zahtevano",
    "Optional" : "Izbirno",
    "Does not attend" : "Ni udeleženec",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ni mogoče določiti časovnega pasu ({tz}), zato bo prikazan čas UTC",
    "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
    "New event" : "Nov dogodek",
    "CalDAV address for clients" : "CalDAV naslov za odjemalce",
    "Error saving WebCal-calendar" : "Napaka shranjevanja koledarja WebCal",
    "WebDAV address for subscriptions" : "WebDAV naslov za naročnike",
    "Email has been sent." : "E-pošta je bila poslana.",
    "There was an issue while sending your email." : "Prišlo je do napake pri pošiljanju e-pošte.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Udeleženci",
    "Reminders" : "Opomniki",
    "Repeating" : "Ponavljanje",
    "When shared show full event" : "Če je v souporabi, pokaži celoten dogodek",
    "When shared show only busy" : "Če je v souporabi, pokaži le podatek o časovni zadržanosti",
    "When shared hide this event" : "Če je v souporabi, skrij ta dogodek",
    "Confirmed" : "Potrjeno",
    "Tentative" : "Začasno",
    "Cancelled" : "Preklicano",
    "Please add a title." : "Dodajte naslov.",
    "Please select a calendar." : "Prosim, izberi koledar!",
    "The event can not end before it starts." : "Dogodek se ne more končati preden se začne.",
    "Global" : "Splošno",
    "None" : "Brez",
    "Every day" : "Vsak dan",
    "Every week" : "Vsak teden",
    "Every month" : "Vsak mesec",
    "Every year" : "Vsako leto",
    "never" : "nikoli",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Kaj če bi najprej poskusil uvoziti kakšen koledar?",
    "At time of event" : "Ob času dogodka",
    "5 minutes before" : "5 minut prej",
    "10 minutes before" : "10 minut prej",
    "15 minutes before" : "15 minut prej",
    "30 minutes before" : "30 minut prej",
    "1 hour before" : "1 uro prej",
    "2 hours before" : "2 uri prej",
    "Custom" : "Po meri",
    "Audio" : "Zvok",
    "Email" : "E-mail",
    "Pop-up" : "Pojavno okno",
    "sec" : "sek",
    "min" : "najmanj",
    "hours" : "ur",
    "days" : "dni",
    "week" : "teden",
    "before" : "pred",
    "start" : "začetek",
    "end" : "konec",
    "Editing reminders of unknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
    "Week {number} of {year}" : "{number}. teden leta {year}",
    "Successfully imported" : "Uvoz uspešno končan",
    "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
    "Partially imported, {n} failures" : "Delno uvoženo, zaznanih je {n} napak",
    "Audio alarm" : "Zvočni alarm",
    "{type} {time} before the event starts" : "{type} {time} preden se dogodek začne",
    "{type} {time} before the event ends" : "{type} {time} preden se dogodek konča",
    "{type} {time} after the event starts" : "{type} {time} po začetku dogodka",
    "{type} {time} after the event ends" : "{type} {time} po koncu dogodka",
    "{type} at the event's start" : "{type} ob začetku dogodka",
    "{type} at the event's end" : "{type} ob koncu dogodka",
    "{type} at {time}" : "{type} ob {time}",
    "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
    "Please enter a valid WebCal-URL" : "Vpišite veljaven naslov URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Resna težava na  webcal proxy. Prosim, kontaktiraj administratorja za dodatne informacije.",
    "Title of the Event" : "Naslov dogodka",
    "Starts" : "Začne",
    "Ends" : "Konča",
    "All day Event" : "Celodnevni dogodek",
    "Delete" : "Izbriši",
    "Cancel" : "Prekliči",
    "More ..." : "Več ...",
    "Create" : "Ustvari",
    "Update" : "Posodobi",
    "Close" : "Zapri",
    "Location" : "Mesto",
    "Description" : "Opis",
    "Event status" : "Stanje dogodka",
    "Visibility when sharing" : "Vidnost med souporabo",
    "Export" : "Izvozi",
    "%s has published the calendar %s" : "%s je objavil koledar \"%s\"",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Te želimo obvestiti, da je %s objavil(a) koledar {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikni tukaj za dostop.",
    "We wanted to inform you that %s has published the calendar %s." : "Te želimo obvestiti, da je %s objavil(a) koledar %s.",
    "Click on the link below to access it" : "Klikni na povezavo, da jo lahko dostopaš",
    "Day" : "Dan",
    "Week" : "Teden",
    "Month" : "Mesec",
    "Today" : "Danes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
    "Share Calendar" : "Omogoči souporabo koledarja",
    "Shared" : "V souporabi",
    "More" : "Več",
    "Edit" : "Uredi",
    "Link" : "Povezava",
    "iCal link" : "iCal povezava",
    "Download" : "Prejmi",
    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
    "can edit" : "lahko ureja",
    "Share link" : "Povezava skupne rabe",
    "Public access" : "Javni dostop",
    "Email link to person" : "Pošlji osebi povezavo po e-pošti",
    "Send" : "Pošlji",
    "New Calendar" : "Nov koledar",
    "Name" : "Ime",
    "New Subscription" : "Novo naročilo",
    "Go back" : "Nazaj",
    "Go forward" : "Naprej",
    "Calendar does not exist" : "Koledar ne obstaja",
    "Maybe you got a wrong link or the calendar was unshared?" : "Mogoče imaš napačno povezavo ali koledar nima skupne rabe?",
    "Edit event" : "Uredi dogodek",
    "Delete Event" : "Izbriši dogodek",
    "Save Event" : "Shrani dogodek",
    "Time" : "Čas",
    "Type" : "Vrsta",
    "Relative" : "Relativno",
    "Absolute" : "Absolutno",
    "Repeat" : "Ponovi",
    "times every" : "krat vsakih",
    "Add" : "Dodaj",
    "Email address of attendee" : "Elektronski naslov udeleženca",
    "Please add your email address in the personal settings in order to add attendees." : "Dodati morate vaš elektronski naslov med osebne nastavitve, preden je mogoče dodajati udeležence",
    "from" : "od",
    "to" : "za",
    "This event's repeating rule is not supported yet." : "Ponavljajoče pravilo tega dogodka še ni podprto.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora naprednejšim pravilom bo dodana z naslednjimi posodobitvami.",
    "Reset repeating rule" : "Ponastavi ponavljajoče se pravilo",
    "Repeat every ..." : "Ponovi na ..",
    "end repeat ..." : "in ponovi ...",
    "times" : "krat",
    "Import Calendars" : "Uvoz koledarjev",
    "Import canceled" : "Uvoz je preklican",
    "Analyzing calendar" : "Preučevanje koledarja",
    "The file contains objects incompatible with the selected calendar" : "Datoteka vsebuje predmete, ki so neskladne z izbranim koledarjem",
    "New calendar" : "Nov koledar",
    "File is empty" : "Datoteka je prazna",
    "Import scheduled" : "Uvoz urnika",
    "%s shared the calendar <strong>%s</strong> with you" : "%s skupno rabo koledarja <strong>%s</strong> z vami",
    "Embed" : "Vdelaj",
    "Iframe to integrate" : "Iframe za integracijo",
    "Publish URL" : "Objavi URL",
    "Settings & import" : "Nastavitve in uvoz",
    "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
    "Show week numbers" : "Pokaži številke tednov",
    "Import calendar" : "Uvoz koledarja",
    "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
    "Primary CalDAV address" : "Osnovni naslov CalDAV",
    "iOS/OS X CalDAV address" : "Naslov CalDAV iOS/OS",
    "Subscribe" : "Naročite se"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
